#
# spec file for package vala
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define         vala_version 0.38
%define         vala_libversion 0_38
# The priority defines which version of vala, in case of multiple ones are installed
# is to be used by default. The rule-of-thumb for vala is to use MAJORMINOR without
# decimal separator, hoping they will not get to the idea to create a 0.100 release.
%define         vala_priority 38
Name:           vala
Version:        0.38.8
Release:        lp150.1.2
Summary:        Programming language for GNOME
License:        LGPL-2.0
Group:          Development/Languages/Other
Url:            https://wiki.gnome.org/Projects/Vala
Source0:        http://download.gnome.org/sources/vala/0.38/%{name}-%{version}.tar.xz

BuildRequires:  bison
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  glib2-devel >= 2.32.0
BuildRequires:  pkgconfig
BuildRequires:  xsltproc
BuildRequires:  pkgconfig(libgvc) >= 2.16
Requires(post): update-alternatives
Requires(postun): update-alternatives
# Vala is a compiler, so it's also a devel package
Provides:       vala-devel = %{version}
Obsoletes:      vala-devel < %{version}
# provide generic pkgconfig(vapigen) instead of -version one; not auto-detected due to %%{_datadir}/pkgconfig/vapigen.pc being %%ghost
Provides:       pkgconfig(vapigen) = %{version}

%description
Vala is an object-oriented programming language with a self-hosting
compiler that generates C code and uses the GObject system.

%package -n libvala-%{vala_libversion}-0
Summary:        Vala programming language runtime
Group:          System/Libraries

%description -n libvala-%{vala_libversion}-0
Runtime library for the Vala programming language.

%package -n libvala-%{vala_libversion}-devel
Summary:        Programming language for GNOME
Group:          Development/Libraries/Other
Requires:       libvala-%{vala_libversion}-0 = %{version}
# Stable name for consumers that support multiple API versions
Provides:       libvala-devel = %{version}

%description -n libvala-%{vala_libversion}-devel
Development files for the Vala runtime library.

%package -n valadoc
Summary:        Generator for API documentation from Vala source
Group:          Development/Tools/Building

%description -n valadoc
Valadoc is a documentation generator for generating API documentation
from Vala source code.

%package -n valadoc-doclet-devhelp
Summary:        Devhelp plugin for the valadoc generator
Group:          Development/Tools/Building

%description -n valadoc-doclet-devhelp
Valadoc is a documentation generator for generating API documentation
from Vala source code.

%package -n valadoc-doclet-gtkdoc
Summary:        Gtkdoc plugin for valadoc
Group:          Development/Tools/Building

%description -n valadoc-doclet-gtkdoc
Valadoc is a documentation generator for generating API documentation
from Vala source code.

%package -n valadoc-doclet-html
Summary:        HTML plugin for valadoc
Group:          Development/Tools/Building

%description -n valadoc-doclet-html
Valadoc is a documentation generator for generating API documentation
from Vala source code.

%package -n libvaladoc-%{vala_libversion}-0
Summary:        Valadoc runtime
Group:          System/Libraries

%description -n libvaladoc-%{vala_libversion}-0
Valadoc is a documentation generator for generating API documentation
from Vala source code.

%package -n libvaladoc-%{vala_libversion}-devel
Summary:        Development files for the valadoc runtime
Group:          Development/Libraries/Other
Requires:       libvaladoc-%{vala_libversion}-0 = %{version}
# Stable name for consumers that support multiple API versions
Provides:       libvaladoc-devel = %{version}

%description -n libvaladoc-%{vala_libversion}-devel
Valadoc is a documentation generator for generating API documentation
from Vala source code.

This package contains the libvaladoc development files.

%prep
%setup -q

%build
%configure --enable-vapigen
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
# Setup update-alternatives
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
ln -s -f %{_sysconfdir}/alternatives/vala %{buildroot}%{_bindir}/vala
ln -s -f %{_sysconfdir}/alternatives/valac %{buildroot}%{_bindir}/valac
ln -s -f %{_sysconfdir}/alternatives/vala-gen-introspect %{buildroot}%{_bindir}/vala-gen-introspect
ln -s -f %{_sysconfdir}/alternatives/vapicheck %{buildroot}%{_bindir}/vapicheck
ln -s -f %{_sysconfdir}/alternatives/vapigen %{buildroot}%{_bindir}/vapigen
ln -s -f %{_sysconfdir}/alternatives/valac.1.gz %{buildroot}%{_mandir}/man1/valac.1.gz
ln -s -f %{_sysconfdir}/alternatives/vala-gen-introspect.1.gz %{buildroot}%{_mandir}/man1/vala-gen-introspect.1.gz
ln -s -f %{_sysconfdir}/alternatives/vapigen.1.gz %{buildroot}%{_mandir}/man1/vapigen.1.gz
ln -s -f %{_sysconfdir}/alternatives/vapigen.pc %{buildroot}%{_libdir}/pkgconfig/vapigen.pc
%fdupes %{buildroot}%{_datadir}

%post
update-alternatives \
  --install %{_bindir}/vala                          vala                     %{_bindir}/vala-%{vala_version} \
            %{vala_priority} \
  --slave   %{_bindir}/valac                         valac                    %{_bindir}/valac-%{vala_version} \
  --slave   %{_bindir}/vala-gen-introspect           vala-gen-introspect      %{_bindir}/vala-gen-introspect-%{vala_version} \
  --slave   %{_bindir}/vapicheck                     vapicheck                %{_bindir}/vapicheck-%{vala_version} \
  --slave   %{_bindir}/vapigen                       vapigen                  %{_bindir}/vapigen-%{vala_version} \
  --slave   %{_mandir}/man1/valac.1.gz               valac.1.gz               %{_mandir}/man1/valac-%{vala_version}.1.gz \
  --slave   %{_mandir}/man1/vala-gen-introspect.1.gz vala-gen-introspect.1.gz %{_mandir}/man1/vala-gen-introspect-%{vala_version}.1.gz \
  --slave   %{_mandir}/man1/vapigen.1.gz             vapigen.1.gz             %{_mandir}/man1/vapigen-%{vala_version}.1.gz \
  --slave   %{_libdir}/pkgconfig/vapigen.pc          vapigen.pc               %{_libdir}/pkgconfig/vapigen-%{vala_version}.pc

%postun
# Note: we don't use "$1 -eq 0", to avoid issues if the package gets renamed
if [ ! -f %{_bindir}/vala-%{vala_version} ]; then
  update-alternatives --remove vala %{_bindir}/vala-%{vala_version}
fi

%post   -n libvala-%{vala_libversion}-0 -p /sbin/ldconfig
%postun -n libvala-%{vala_libversion}-0 -p /sbin/ldconfig

%post   -n libvaladoc-%{vala_libversion}-0 -p /sbin/ldconfig
%postun -n libvaladoc-%{vala_libversion}-0 -p /sbin/ldconfig

%files
%doc AUTHORS ChangeLog COPYING NEWS README
%{_bindir}/vala
%{_bindir}/valac
%{_bindir}/vala-gen-introspect
%{_bindir}/vapicheck
%{_bindir}/vapigen
%{_mandir}/man1/valac.1*
%{_mandir}/man1/vala-gen-introspect.1*
%{_mandir}/man1/vapigen.1*
%{_libdir}/pkgconfig/vapigen.pc
%ghost %attr(755,root,root) %{_sysconfdir}/alternatives/vala
%ghost %attr(755,root,root) %{_sysconfdir}/alternatives/valac
%ghost %attr(755,root,root) %{_sysconfdir}/alternatives/vala-gen-introspect
%ghost %attr(755,root,root) %{_sysconfdir}/alternatives/vapicheck
%ghost %attr(755,root,root) %{_sysconfdir}/alternatives/vapigen
%ghost %attr(644,root,root) %{_sysconfdir}/alternatives/valac.1.gz
%ghost %attr(644,root,root) %{_sysconfdir}/alternatives/vala-gen-introspect.1.gz
%ghost %attr(644,root,root) %{_sysconfdir}/alternatives/vapigen.1.gz
%ghost %attr(644,root,root) %{_sysconfdir}/alternatives/vapigen.pc
%{_bindir}/vala-%{vala_version}
%{_bindir}/valac-%{vala_version}
%{_bindir}/vala-gen-introspect-%{vala_version}
%{_bindir}/vapicheck-%{vala_version}
%{_bindir}/vapigen-%{vala_version}
%{_mandir}/man1/valac-%{vala_version}.1*
%{_mandir}/man1/vala-gen-introspect-%{vala_version}.1*
%{_mandir}/man1/vapigen-%{vala_version}.1*
%{_datadir}/aclocal/vala.m4
%{_datadir}/aclocal/vapigen.m4
%{_libdir}/pkgconfig/vapigen-%{vala_version}.pc
%dir %{_datadir}/vala
%{_datadir}/vala/Makefile.vapigen
%{_datadir}/vala-%{vala_version}/
%{_libdir}/vala-%{vala_version}/

%files -n valadoc
%{_bindir}/valadoc
%{_bindir}/valadoc-%{vala_version}
%{_mandir}/man1/valadoc*.1%{?ext_man}

%files -n valadoc-doclet-devhelp
%dir %{_libdir}/valadoc
%dir %{_libdir}/valadoc/doclets
%{_libdir}/valadoc/doclets/devhelp/

%files -n valadoc-doclet-gtkdoc
%dir %{_libdir}/valadoc
%dir %{_libdir}/valadoc/doclets
%{_libdir}/valadoc/doclets/gtkdoc/

%files -n valadoc-doclet-html
%dir %{_libdir}/valadoc
%dir %{_libdir}/valadoc/doclets
%{_libdir}/valadoc/doclets/html/

%files -n libvala-%{vala_libversion}-0
%{_libdir}/libvala-%{vala_version}.so.*

%files -n libvaladoc-%{vala_libversion}-0
%{_libdir}/libvaladoc-%{vala_version}.so.*

%files -n libvala-%{vala_libversion}-devel
%{_includedir}/vala-%{vala_version}/
%{_libdir}/libvala-%{vala_version}.so
%{_libdir}/pkgconfig/libvala-%{vala_version}.pc
%dir %{_datadir}/devhelp/
%dir %{_datadir}/devhelp/books/
%{_datadir}/devhelp/books/%{name}-%{vala_version}/
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/libvala-%{vala_version}.vapi

%files -n libvaladoc-%{vala_libversion}-devel
%{_includedir}/valadoc-%{vala_version}/
%{_libdir}/libvaladoc-%{vala_version}.so
%{_datadir}/valadoc/
%{_libdir}/pkgconfig/valadoc-%{vala_version}.pc
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/valadoc-%{vala_version}.*

%changelog
* Thu Feb 15 2018 bjorn.lie@gmail.com
- Update to version 0.38.8:
  + Various bug fixes:
  - Fix GDestroyNotify of delegate parameters in delegate
    declaration (bgo#639059).
  - Avoid critical when connecting dynamic signals.
  - compiler: Prefix headers for set_cheader_override() if
    includedir is given (bgo#793299).
  - Don't warn about unused internal methods which are meant to
    be visible on DBus (bgo#593902).
  - libvaladoc: Prevent WITH_CGRAPH conditional having an impact
    on generated sources.
  + Bindings:
  - gio-2.0: Cherry-pick some DBusProxy fixes from 0.40.
  - gstreamer-1.0: Update from 1.13+ git master.
  - gdk-3.0,gtk+-3.0: Update to 3.22.27.
- Update vala_priority define to 38, something we should have done
  when stable 0.38.0 was released.
* Sun Feb  4 2018 bjorn.lie@gmail.com
- Update to version 0.38.7:
  + Regression fix: codegen: Don't try to infer error argument on
    async begin methods (bgo#793158). This was a regression
    introduced by (bgo#614294).
* Wed Jan 31 2018 bjorn.lie@gmail.com
- Update to version 0.38.6:
  + Various bug fixes:
  - girparser:
    . Set NoAccessorMethod for non-readable and construct-only
    properties.
    . Ignore conflicting closure/destroy indexes.
    . Don't accept methods as property-accessor which throw
    errors (bgo#792998).
  - codegen:
    . Infer error parameter from abstract/virtual base methods
    (bgo#614294).
    . Fix return-type for cancelled async creation methods of
    classes (bgo#792942).
  - vala: Variadic constructors without a real first parameter
    are not allowed.
  - libvaladoc: Keep bootstrap-support with valac >= 0.16.1.
  + Bindings:
  - gstreamer-1.0: Update from 1.13+ git master.
  - gtk+-4.0: Only override type of "event" parameters.
* Mon Jan 22 2018 bjorn.lie@gmail.com
- Update to version 0.38.5:
  + Various improvements and bug fixes:
  - codegen:
    . Only add property-enum and GParamSpec-array for GObject
    classes
    . Add destroy param when invoking delegate returned by
    delegate (bgo#792077).
  - vala:
    . Add pkgdatadir and pkglibdir to pkg-config file.
    . Fix parameter type inference of overridden async methods
    (bgo#792660).
  - gidlparser: Update type qualifiers.
  - libvaladoc:
    . Allow @link tags to be split over multiple lines
    (bgo#646982).
    . Add support for single line documentation comments
    (bgo#736483).
  - codewriter: Don't use string.replace() to apply
    header_to_override (bgo#731322).
  + Bindings:
  - glib-2.0: Add GLib.OPTION_REMAINING and
    GLib.OptionFlags.NONE.
  - gstreamer-1.0: Update from 1.13+ git master.
  - gtk+-2.0: Mark MessageDialog constructor parameter,
    message_format, as nullable (bgo#791570).
  - gtk+-2.0/3.0: Don't hide user_data in
    Clipboard.set_with_data() (bgo#792237).
  - gtk+-3.0: Update to 3.22.26+6f26d0dc.
  - gtk+-4.0: Update to 3.93.0 and split Gsk.RenderNode into
    several classes.
  - libwnck-3.0: Update to 3.24.1.
  - posix: Add ctime(3) and fix binding of struct hostent and
    gethostbyname(3).
  - webkit2gtk-4.0: Update to 2.19.5.
  - webkit2gtk-web-extension-4.0: Fix DOM.EventTarget interface.
- Drop vala-fix-MessageDialog-constructor-parameter.patch: Fixed
  upstream.
- Following the above, drop libtool BuildRequires and autoreconf
  call, no longer needed as we do not carry any patches anymore.
* Mon Dec 18 2017 zaitor@opensuse.org
- Update to version 0.38.4:
  + Various bug fixes:
  - Enforce name-length >= 3 for structs using GType
    (bgo#764041).
  - Report error for missing type-parameter on enclosing type
    (bgo#587905).
  - Discover invalid member access to instance field
    (bgo#790903).
  - Improve error output of mismatching overriding methods.
  - vala: Don't transform an explicit "null" into valid
    format-string (bgo#791215).
  - codegen: Don't create null-safe destroy-wrapper for
    GenericType (bgo#791283).
  - Improve error message for missing type-parameter on enclosing
    type (bgo#587905).
  + GIR parser:
  - Allow change of parameter names.
  - Handle metadata for fields inside a transparent union.
  - Accept setters with boolean return-type as valid
    property-accessor.
  - Don't mark simple-type out-parameters with '?' as nullable.
  + Valadoc:
  - Acknowledge possible properties in structs (bgo#784705).
  - Fix fatal typo in GtkdocRenderer.visit_symbol_link()
    (bgo#790266).
  - libvaladoc: Actually resolve "percnt;" to '%%'.
  + Bindings:
  - gobject-2.0: Add some missing symbols.
  - gstreamer-1.0: Bind GST_DEBUG_BIN_TO_DOT_FILE/*_WITH_TS
    (bgo#785215).
  - gstreamer-1.0: Update from 1.13+ git master.
  - gtk+-3.0: Update to 3.22.26+9ce824d3.
  - webkit2gtk-4.0: Update to 2.19.2.
  - glib-2.0: Fix potential null pointer dereference in
    string.joinv() (bgo#791257).
  - gobject-2.0: Add missing GType constants for fundamentals
    (bgo#791023).
- Add vala-fix-MessageDialog-constructor-parameter.patch: Mark
  MessageDialog constructor parameter, message_format, as nullable
  (bgo#791570).
- Following the above, add libtool BuildRequires and pass
  autoreconf, make sure vapi deps get regenerated after patch is
  applied.
* Thu Nov  9 2017 fezhang@suse.com
- Update to version 0.38.3:
  + Various bug fixes:
  - codegen: Prioritize "array_length=true" over
    "array_null_terminated=true" (bgo#788775).
  - codegen: Avoid possible conflicts with internal
    property/signal defines (bgo#788964).
  + Bindings:
  - gio-2.0: Expose g_task_get_source_object as
    Task.get_unowned_source_object.
  - gstreamer-1.0: Update from 1.13+ git master.
  - gtk+-4.0: Update to 3.92.1.
  - libxml-2.0: Add DTD methods (bgo#789442).
* Mon Oct  9 2017 luc14n0@linuxmail.org
- Update to version 0.38.2:
  + Various bindings updates:
  - gstreamer-1.0, gtk+-3.0, gtk+-4.0: Update from git master.
  - gnutls: Fix free_function ccode-attribute of Certificate
    (bgo#788181).
- Update Url to https://wiki.gnome.org/Projects/Vala: current Vala
  web page.
* Mon Sep 11 2017 zaitor@opensuse.org
- Update to version 0.38.1:
  + Various bug fixes:
  - valadoc: Don't use 'stderr' as variable name (bgo#787305).
  - codegen: Try to use a more unique internal define for
    properties (bgo#787436).
  - vala: Update list of used attributes.
  - method: Use prototype-string for error-reports of return-type
    mismatches.
  + Bindings: glib-2.0: Fix MainContext.check(),  OptionEntry[]
    params are null-terminated, Bind g_convert_with_fallback() and
    g_convert_with_iconv()
* Tue Sep  5 2017 jengelh@inai.de
- Correct RPM groups and package descriptions.
- Remove --with-pic which is for static libs only.
* Mon Sep  4 2017 zaitor@opensuse.org
- Update to version 0.38.0:
  + Various bug fixes:
  - Improve error output for incompatible method signatures (Add
    CallableType as base for DelegateType, MethodType,
    SignalType).
  - codegen:
    . Initialize temp-variable for fixed-size arrays to zero
    first (bgo#787152).
    . Add support for "type-func" in ui-files (bgo#787033).
  + Bindings:
  - gtk+-3.0,gtk+-4.0: Update.
  - libxml-2.0: Bind xmlLastElementChild and
    xmlPreviousElementSibling
  - pangocairo: CairoFontMap.set_default() is not an instance
    method.
  - gio-2.0: Application.set_default() is not an instance method.
* Mon Aug 28 2017 zaitor@opensuse.org
- Update to version 0.37.91:
  + Various bug fixes:
  - codegen:
    . Actually write declaration for GNodeTraverseFunc wrapper
    (bgo#786845).
    . Don't transfer ownership of variable if target-type is
    unknown (bgo#736774).
    . Adjust format-index for printf/scanf-methods which throw
    errors (bgo#781061).
    . Use given dup_function for structs.
  - libvaladoc: Fix some -Wincompatible-pointer-types warnings.
  - tests: Fix some syntax issues [#786652]
  - Add .editorconfig file [#786620]
  + GIR parser:
  - Better support of "cprefix" argument in metadata.
  - Support "cname" argument in metadata.
  + Bindings:
  - Add javascriptcoregtk-4.0 and avoid skips in webkit2gtk*-4.0.
  - Update GIR-based bindings.
  - gtk+-3.0: Update to 3.22.19.
* Mon Aug 21 2017 zaitor@opensuse.org
- Update to version 0.37.90:
  + Various bug fixes:
  - Fix some build-system problem:
    . valadoc/tests: Add the source vapi directory to driver-test
    (bgo#786505).
    . Add ./vala/.libs rather than ./gee/.libs to
    LD_LIBRARY_PATH.
    . Explicitly link doclets against libvala-*.la (bgo#786534).
    . Add missing include of Makefile.common.
  - vapigen: Mark given source-files as such and force girparser
    to handle them.
  - codegen: Include glib-object.h for Enums/Structs with
    type_id.
  + Bindings: gtk+-4.0: Make Gsk.Texturer.for_*() static factory
  methods.
* Tue Aug 15 2017 zaitor@opensuse.org
- Update to version 0.37.2:
  + Various bug fixes:
  - libvaladoc: Keep bootstrap-support with valac >= 0.16.1.
  - valadoc: Fix tests while bootstapping with valac < 0.31/32.
  + Bindings:
  - glib-2.0: Update Unicode symbols.
  - gobject-2.0: Add required type_id attributes to all ParamSpec
    subclasses.
  - libgdata: Make Authorizer.reauth_* methods virtual
    (bgo#779229).
  - libxml-2.0: Update Xml.ParserOption (bgo#785585).
  - gtk+-4.0: Update to 3.91.2.
  - webkit2gtk-4.0: Update to 2.17.90.
- Drop vala-no-nullable-enum.patch: Fixed upstream, following this
  drop vala BuildRequires, no longer needed.
* Thu Jul 20 2017 dimstar@opensuse.org
- Update to version 0.37.1:
  + Highlights:
  - Don't warn about deprecated symbols if installed_version is
    older.
  - Add --gresourcesdir option (bgo#783133).
  - Install libvala-0.xx.vapi to "global" vapi directory.
  - Require and target GLib >= 2.40.
  - build: Make ccode and codegen private API.
  - build: Use --use-header for vala's libraries.
  - compiler: Add --color=WHEN option.
  - codegen: Use g_object_notify_by_pspec() to notify
    property-changes.
  - codegen: Use *_free_full to free GLib.List, GLib.SList and
    GLib.Queue.
  - codegen: Support renamed signals (bgo#731547).
  - Optimize (de)serialization of arrays with type-signature "ay"
    (bgo#772426).
  - Merge valadoc - Consider valadoc a part of vala's toolchain
    and therefore let it live in the main repository (adds
    graphviz to the build-requirements)
  + Various bug fixes:
  - Fix finally blocks with async yields (bgo#741929).
  - Handle non-null in coalescing expression (bgo#611223).
  - Make the task_complete flag for < 2.44 more similar to >=
    2.44 (bgo#783543).
  - Nullable ValueType requires POINTER as marshaller signature
    (bgo#783897).
  - NoAccessorMethod attribute is allowed for gobject-properties
    only.
  - girparser: Fix parsing of delegate-alias without target.
  - compiler: Use API_VERSION instead of stripping
    PACKAGE_SUFFIX.
  - girwriter: Write length-parameters of arrays with rank > 1
    (bgo#758019).
  - gdbus: Don't leak nested HashTable on deserialization
    (bgo#782719).
  - codewriter: Update timestamps of generated c-files if needed
    (bgo#683286).
  - tests: Use dbus-run-session instead of dbus-launch
    (bgo#771455).
  - codegenerator: Add source_reference parameter to
    CodeGenerator.store_*().
  - Don't allow assigning delegate if no target/closure is
    available (bgo#598869).
  - gee: Add some useful symbols from gee-0.8.
  + Bindings:
  - gio-2.0:
    . Add DBusConnection 'closed' signal as 'on_closed'
    (bgo#684358).
    . Use default 'length = null' for
    DataInputStream.read_line_utf8* (bgo#783351).
  - glib-2.0,gobject-2.0: Updates from 2.53.x.
  - poppler-glib: Update to 0.54.0.
  - webkit2gtk-4.0: Update to 2.17.4.
  - gstreamer-1.0: Update to 1.13.0+.
  - libgvc: Add WITH_CGRAPH conditionals.
- Add pkgconfig(libgvc) BuildRequires: new dependency.
- split out new packages: valadoc,
  valadoc-docklet-{devhelp,gtkdoc,html}, libvaladoc-0_38-0 and
  libvaladoc-0_38-devel.
- Add vala-no-nullable-enum.patch: Fix 64bit portability issues
  (bgo#784927).
- Add vala BuildRequires: as above patch touches the source .vala
  files, we need to bootstrap.
* Mon Jun 26 2017 zaitor@opensuse.org
- Update to version 0.36.4:
  + Highlights:
  - Don't warn about deprecated symbols if installed_version is
    older.
  - Add --gresourcesdir option (bgo#783133).
  + Various bug fixes:
  - gdbus: Don't leak nested HashTable on deserialization
    (bgo#782719).
  - Fix finally blocks with async yields (bgo#741929).
  - Handle non-null in coalescing expression (bgo#611223).
  - Make the task_complete flag for < 2.44 more similar to >=
    2.44 (bgo#783543).
  - Nullable ValueType requires POINTER as marshaller signature
    (bgo#783897).
  - NoAccessorMethod attribute is allowed for gobject-properties
    only.
  - girparser: Fix parsing of delegate-alias without target.
  - compiler: Use API_VERSION instead of stripping
    PACKAGE_SUFFIX.
  - girwriter: Write length-parameters of arrays with rank > 1
    (bgo#758019).
  + Bindings:
  - gio-2.0: Use default 'length = null' for
    DataInputStream.read_line_utf8* (bgo#783351).
  - gobject-2.0: Add GLib.ParamSpecPointer.
  - poppler-glib: Update to 0.54.0.
  - gstreamer-1.0: Various binding fixes.
* Wed May 10 2017 zaitor@opensuse.org
- Update to version 0.36.3:
  + Various bug fixes:
  - scanner: Fix calculation of column value for tokens after
    multiline comment (bgo#652899).
  - codegen: Unref GLib.AsyncResult on uncaught errors in
    coroutines (bgo#641171).
  - Keep initializing result-variable for struct constructors
    (bgo[#782056).
* Wed Apr 26 2017 dimstar@opensuse.org
- Update to version 0.36.2:
  + Enums require at least one value otherwise report an error.
  + Bindings:
  - gstreamer-1.0: Update to 1.11.90+.
  - gio-2.0: Fix GLib.Task constructor and
    report_error/report_new_error()
  - glib-2.0:
    . Add quark() functions to errordomains.
    . Add missing version macro and constants.
* Tue Apr  4 2017 zaitor@opensuse.org
- Update to version 0.36.1:
  + Various bug fixes:
  - Always consider a method compatible with itself (bgo#773135).
  - Perform arguments-check against actual .end()
    method-signature (bgo#684208).
  - Slightly improve lamdba-expression error on target-type
    mismatch.
  - Fix delegate initializer for instance fields (bgo#683925).
  - Don't leak target-reference when casting/assigning owned
    delegates (bgo#780426).
  + GIR parser and writer:
  - girparser: Add destroy argument for metadata (bgo#750838).
  - vapigen: Add --nostdpkg option like in valac.
  + Bindings:
  - gstreamer-1.0: Fix Pad.set_*_function() bindings
    (bgo#750838).
  - glib-2.0: Add missing version macro and constants, unichar
    .to_string doesn't return null.
  - gtk+-2.0,gtk+-3.0: Mark "intersection" param of
    Widget.intersect() as out.
  - gtk+-4.0: Update to 3.90.0.
* Sun Mar 19 2017 dimstar@opensuse.org
- Update to version 0.36.0:
  + Bugs fixed: bgo#740303, bgo#758816, bgo#779968, bgo#780050.
* Mon Mar 13 2017 dimstar@opensuse.org
- Update to version 0.35.90:
  + Bug fixes and binding updates.
* Tue Mar  7 2017 zaitor@opensuse.org
- Update to version 0.35.7:
  + Bug fixes and binding updates.
  + Add libgrss binding.
  + Introduce [CCode (finish_instance = ...)] attribute.
  + Update manpages.
* Mon Feb 27 2017 zaitor@opensuse.org
- Update to version 0.35.6:
  + Bug fixes and binding updates.
* Tue Feb 14 2017 zaitor@opensuse.org
- Update to version 0.35.5:
  + Fix regression.
- Changes from version 0.35.4:
  + Bug fixes and binding updates.
* Tue Jan 10 2017 zaitor@opensuse.org
- Update to version 0.35.3:
  + Bug fixes and binding updates.
  + Add gtk+-unix-print-{2,3,4}.0 bindings.
* Wed Dec 14 2016 dimstar@opensuse.org
- Update to version 0.35.2:
  + Bug fixes and binding updates.
* Wed Dec 14 2016 dimstar@opensuse.org
- Update to version 0.35.1:
  + Ignore --thread command-line option which is obsolete.
  + Fix type checking when using generics.
  + Use g_signal_emit where possible.
  + Introduce [FormatArg] attribute for parameters.
  + Use GTask API for async implementations with
    target-gLib >= 2.36.
- Bump vala_version to 0.36, vala_libversion to 0_36 (following
  upstream) and vala_priority to 36 (following the vala packaging
  convention).
* Tue Dec 13 2016 adam.majer@suse.de
- Fix descriptions so they actually describe subpackages.
- Have the -devel package provide libvala-devel: this allows
  consumers to require libvala without version constraints. They
  will still have to follow the API changes though.
* Mon Dec  5 2016 dimstar@opensuse.org
- Update to version 0.34.4:
  + Bug fixes.
* Wed Nov 23 2016 zaitor@opensuse.org
- Update to version 0.34.3:
  + Bug fixes and binding updates.
* Sun Oct 23 2016 zaitor@opensuse.org
- Update to version 0.34.2:
  + Bug fixes and binding updates.
* Mon Oct 10 2016 zaitor@opensuse.org
- Update to version 0.34.1:
  + Add support for the \v escape character.
  + Bug fixes and binding updates.
* Mon Sep 19 2016 zaitor@opensuse.org
- Update to version 0.34.0:
  + Bug fixes and binding updates.
- Update update alternatives due to moved location of vapigen.pc
* Wed Sep 14 2016 dimstar@opensuse.org
- Update to version 0.33.1:
  + Bug fixes and binding updates.
- Bump vala_version to 0.34, vala_libversion to 0_34 (following
  upstream) and vala_priority to 34 (following the vala packaging
  convention).
* Mon Jun 20 2016 zaitor@opensuse.org
- Update to version 0.32.1:
  + Bug fixes and binding updates.
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 0.32.0:
  + Bug fixes and binding updates.
* Mon Feb  8 2016 dimstar@opensuse.org
- Update to version 0.31.1:
  + Introduce [Version] attribute.
  + Require and target GLib >= 2.32.
  + Bug fixes and binding updates.
- Bump vala_version to 0.32, vala_libversion to 0_32 (following
  upstream) and vala_priority to 32 (following the vala packaging
  convention).
* Mon Feb  1 2016 dimstar@opensuse.org
- Update to version 0.30.1:
  + Bug fixes and binding updates.
* Fri Sep 18 2015 dimstar@opensuse.org
- Update to version 0.30.0:
  + Binding updates.
  + Bugs fixed: bgo#752031.
- Bump vala_priority to 30.
* Tue Aug 11 2015 zaitor@opensuse.org
- Update to version 0.29.3:
  + Add --shared-library option for GIR files.
  + Bug fixes and binding updates.
* Tue Aug 11 2015 zaitor@opensuse.org
- Update to version 0.29.2:
  + Bug fixes and binding updates.
* Tue Aug 11 2015 zaitor@opensuse.org
- Update to version 0.29.1:
  + Binding updates.
* Tue Aug 11 2015 zaitor@opensuse.org
- Update to version 0.28.1:
  + Bug fixes and binding updates.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 0.28.0:
  + Binding updates.
* Thu Mar 19 2015 dimstar@opensuse.org
- Update to version 0.27.2:
  + Bug fixes and binding updates.
* Wed Jan 28 2015 zaitor@opensuse.org
- Update to version 0.27.1:
  + Print compiler messages in color.
  + Add clutter-gdk-1.0 bindings.
  + Add clutter-gst-3.0 bindings.
  + Add clutter-x11-1.0 bindings.
  + Add rest-extras-0.7 bindings.
  + Bug fix and binding updates.
- Bump vala_version to 0.28, vala_libversion to 0_28 and
  vala_priority to 28, following upstreams changes.
* Fri Jan 16 2015 zaitor@opensuse.org
- Update to version 0.26.2:
  + Bug fixes and binding updates.
* Thu Nov 13 2014 olaf@aepfle.de
- Add attr to ghost entries in file list to fix build in SLE_11
* Mon Oct 13 2014 dimstar@opensuse.org
- Update to version 0.26.1:
  + Bug fixes and binding updates.
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 0.26.0:
  + Bug fix and binding updates.
* Mon Sep 15 2014 zaitor@opensuse.org
- Update to version 0.25.4:
  + Add option --vapi-comments.
  + Bug fixes and binding updates.
  + Updated translations.
* Mon Sep  1 2014 zaitor@opensuse.org
- Update to version 0.25.3:
  + Bug fixes and binding updates.
* Sun Aug 24 2014 zaitor@opensuse.org
- Update to version 0.25.2:
  + Report warning for private struct fields.
  + Replace webkit2gtk-3.0 bindings with webkit2gtk-4.0 bindings.
  + Always build vapigen.
  + Bug fixes and binding updates.
* Wed Jul 23 2014 dimstar@opensuse.org
- Update to version 0.25.1:
  + Support explicit interface method implementation.
  + Support (unowned type)[] syntax.
  + Support non-literal length in fixed-size arrays.
  + Mark regular expression literals as stable.
  + GIR parser updates.
  + Add webkit2gtk-3.0 bindings.
  + Add gstreamer-allocators-1.0 and gstreamer-riff-1.0 bindings.
  + Bug fixes and binding updates.
- Bump vala_version to 0.26, vala_libversion to 0_26 and
  vala_priority to 26, following upstreams changes.
- Correct update-alternatives usage.
- Add pkgconfig(vapigen) Provides: due to the correct usage of
  update-alternatives, %%{_datadir}/pkgconfig/vapigen.pc is now only
  as %%ghost in the package; this results in the file not being
  processed for Requires and Provides.
* Mon Mar 24 2014 zaitor@opensuse.org
- Update to version 0.24.0:
  + Bug fixes and binding updates.
* Tue Feb 18 2014 zaitor@opensuse.org
- Update to version 0.23.3:
  + Bug fixes and binding updates.
* Wed Feb  5 2014 dimstar@opensuse.org
- Update to version 0.23.2:
  + Bind GDK event structures as compact classes.
  + Switch gdk-x11-3.0 bindings to .gir.
  + Switch librsvg-2.0 bindings to .gir.
  + Bug fixes and binding updates.
* Sun Dec 22 2013 zaitor@opensuse.org
- Update to version 0.23.1:
  + Switch libnotify bindings to .gir.
  + Add libpeas-gtk-1.0 bindings.
  + Add xcb-icccm bindings.
- Change vala_version to 0.24 and vala_priority to 24, following
  upstreams versioning.
* Wed Nov 13 2013 dimstar@opensuse.org
- Update to version 0.22.1 (bnc#849913):
  + Support chain up to constructv functions.
  + Bug fixes and binding updates.
* Mon Sep 23 2013 zaitor@opensuse.org
- Update to version 0.22.0:
  + Support chain up to constructv functions.
  + Bug fixes and binding updates.
* Fri Sep 13 2013 dimstar@opensuse.org
- Update to version 0.21.2:
  + Recognize ref/unref functions in .gir files.
  + Add geocode-glib bindings.
  + Bug fixes and binding updates.
* Fri Aug  2 2013 dimstar@opensuse.org
- Update to version 0.21.1:
  + Support \uXXXX escape sequences.
  + Support specifying vfunc order in interfaces to define ABI.
  + Support GTK+ widget templates.
  + Bug fixes and binding updates.
- Change vala_version to 0.22 and vala_priority to 22, following
  upstreams versioning.
* Mon Apr  8 2013 dimstar@opensuse.org
- Update to version 0.20.1:
  + Bug fixes.
* Tue Mar 26 2013 dimstar@opensuse.org
- Update to version 0.20.0:
  + Bug fixes and binding updates.
* Wed Feb 20 2013 dimstar@opensuse.org
- Update to version 0.19.0:
  + Support scope = "async" attribute for parameters.
  + Add --api-version option.
  + Add atspi-2 bindings.
  + Add gstreamer-rtsp-server-1.0 bindings.
  + Bug fixes and binding updates.
* Wed Nov 14 2012 dimstar@opensuse.org
- Update to version 0.18.1:
  + Bug fixes and binding updates.
* Wed Oct 17 2012 dimstar@opensuse.org
- Add xsltproc BuildRequires: Needed to to build the devhelp books.
- Drop xz BuildRequires, as it now comes for free in the build
  system.
* Mon Sep 24 2012 dimstar@opensuse.org
- Update to version 0.18.0:
  + Bug fixed: bgo#683922.
* Sun Sep 16 2012 dimstar@opensuse.org
- Update to version 0.17.7:
  + Add libgnome-menu-3.0 bindings.
  + Bug fixes and binding updates.
* Mon Sep  3 2012 dimstar@opensuse.org
- Update to version 0.17.6:
  + Bug fixes and binding updates.
* Mon Aug 20 2012 dimstar@opensuse.org
- Update to version 0.17.5:
  + Support subclassing of GLib.Source.
  + Switch pango bindings to .gir.
  + Add gstreamer-1.0 core bindings.
  + Add gst-plugins-base-1.0 bindings.
  + Add gobject-introspection-1.0 bindings.
  + Bug fixes and binding updates.
* Mon Aug  6 2012 dimstar@opensuse.org
- Update to version 0.17.4:
  + Warn when accessing static members with an instance reference.
  + Recompute length when casting between array types.
  + Support [GenericAccessors] attribute for interfaces.
  + Deprecate implicit .begin for async methods.
  + Drop Dova profile.
  + Drop POSIX profile.
  + Bug fixes and binding updates.
* Tue Jul 17 2012 dimstar@opensuse.org
- Update to version 0.17.3:
  + Require and target GLib >= 2.18.
  + Support async creation methods.
  + Bug fixes and binding updates.
* Mon Jun 25 2012 dimstar@opensuse.org
- Update to version 0.17.2:
  + Bug fixes and binding updates.
* Sun Jun 24 2012 dimstar@opensuse.org
- Update to version 0.17.1:
  + Improve assertion messages.
  + Add --enable-gobject-tracing commandline option.
  + Bug fixes and binding updates.
* Sun Jun 24 2012 dimstar@opensuse.org
- Update to version 0.17.0:
  + Support simple method-level profiling.
  + Add VALA_CHECK_MODULES and VALA_PROG_VAPIGEN to vala.m4.
  + Bug fixes and binding updates
* Sun Jun 24 2012 zaitor@opensuse.org
- Update to version 0.16.1:
  + Bug fixes and binding updates.
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 0.16.0:
  + Add udisks2 bindings.
  + Bug fixes and binding updates.
* Sat Feb 25 2012 zaitor@opensuse.org
- Update to version 0.15.2:
  + Switch poppler-glib bindings to .gir.
  + Many bug fixes and binding updates.
* Fri Jan 27 2012 vuntz@opensuse.org
- Update to version 0.15.1:
  + Support arrays with nullable elements.
  + Add <doc> support to .gir reader and writer.
  + Switch clutter-gtk-1.0 bindings to .gir.
  + Switch gio-2.0 bindings to .gir.
  + Add cogl-pango-1.0 bindings.
  + Add gdl-3.0 bindings.
  + Add libnl-3.0 bindings.
  + Add packagekit-glib2 bindings.
  + Add xtst bindings.
  + Many bug fixes and binding updates.
* Tue Dec  6 2011 dimstar@opensuse.org
- Update to version 0.15.0:
  + Manage memory of GQueue elements.
  + Switch atk bindings to .gir.
  + Switch gdk-pixbuf-2.0 bindings to .gir.
  + Switch gdk-3.0 bindings to .gir.
  + Add libwnck-3.0 bindings.
  + Many bug fixes and binding updates.
- Change the various %%define in spec file to use 0.16 version.
* Wed Nov 30 2011 dimstar@opensuse.org
- Update to version 0.14.1:
  + Add libwnck-3.0 bindings.
  + Many bug fixes and binding updates.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that...
  See bnc#697467 for more details.
* Sun Sep 18 2011 vuntz@opensuse.org
- Update to version 0.14.0:
  + Bug fixes and binding updates.
* Wed Sep  7 2011 vuntz@opensuse.org
- Update to version 0.13.4:
  + Switch gudev-1.0 bindings to .gir.
  + Switch mx-1.0 bindings to .gir.
  + Many bug fixes and binding updates.
- Drop vala-markupparser-fix.patch: fixed upstream.
* Mon Sep  5 2011 vuntz@opensuse.org
- Add vala-markupparser-fix.patch: this fixes GMarkupParser
  bindings, which enables a new fillmode-lombard to build.
* Mon Aug 22 2011 dimstar@opensuse.org
- Update to version 0.13.3:
  + Switch pangocairo bindings to .gir.
  + Bug fixes.
* Wed Aug 17 2011 dimstar@opensuse.org
- Update to version 0.13.2:
  + Enable flow analysis for out parameters.
  + Refactor attribute handling.
  + Add gedit-3.0 bindings.
  + Add gtksourceview-3.0 bindings.
  + Add rest-0.7 bindings.
  + Add vte-2.90 bindings.
  + Switch clutter-1.0 bindings to .gir.
  + Switch libgdata bindings to .gir.
  + Switch libsoup bindings to .gir.
  + Many bug fixes and binding updates.
* Wed Jul  6 2011 vuntz@opensuse.org
- Update to version 0.13.1:
  + Many bug fixes and binding updates.
* Fri Jun 24 2011 dimstar@opensuse.org
- Update to version 0.13.0:
  + More refactoring in the code generator.
  + Improvements to the .gir reader.
  + Switch JSON-GLib bindings to .gir.
  + Drop deprecated support for D-Bus GLib in favor of GDBus.
  + Many bug fixes and binding updates.
- Adjust vala_version, vala_libversion and priority for 0.13.
* Thu Jun  2 2011 dimstar@opensuse.org
- Update to version 0.12.1:
  + Many bug fixes and binding updates.
* Mon Apr  4 2011 dimstar@opensuse.org
- Update to version 0.12.0:
  + Add get_next_char to string class.
  + Many bug fixes and binding updates.
- Changes from version 0.11.7:
  + Add support for async signal handlers.
  + More refactoring in the code generator.
  + Improvements to the .gir writer.
  + Many bug fixes and binding updates.
- Changes from version 0.11.6:
  + Add parse and try_parse methods to boolean and numeric types.
  + Add clutter-gtk-1.0 bindings.
  + Add pixmap-1 bindings.
  + Many bug fixes and binding updates.
- Changes from version 0.11.5:
  + Add last_index_of and last_index_of_char to string class.
  + More refactoring in the code generator.
  + Improvements to the .gir writer.
  + Many bug fixes and binding updates.
- Changes from version 0.11.4:
  + Add index_of, index_of_char, and char_count to string class.
  + Many bug fixes and binding updates.
- Changes from version 0.11.3:
  + Support BusName sender parameter in GDBus servers.
  + More refactoring in the code generator.
  + Many bug fixes and binding updates.
- Changes from version 0.11.2:
  + Update libnotify bindings to 0.7.0.
  + Improvements to the .gir reader.
  + Bug fixes and binding updates.
- Changes from version 0.11.1:
  + Require and target GLib >= 2.16.
  + Guard access to out parameters to allow null arguments.
  + Add support for local constants.
  + Support file descriptor passing with GDBus.
  + Support cached property values in GDBus clients.
  + Support Cancellable parameter in GDBus clients.
  + Support no-reply methods in GDBus clients and servers.
  + More refactoring in the code generator.
  + Many bug fixes and binding updates.
- Changes from version 0.11.0:
  + Use byte indices for strings.
  + Use uint8[] for binary data in bindings.
  + Add support for parallel compilation.
  + Improve compiler performance.
  + More refactoring in the code generator.
  + Many bug fixes and binding updates.
- Drop vala-bgo638902-shotwell-fix.patch: fixed upstream.
* Sun Jan  9 2011 vuntz@opensuse.org
- Change the test for update-alternatives in %%postun to not check
  if the package is still installed, but to check if the binary is
  still there, to handle package renamings.
* Sun Jan  9 2011 vuntz@opensuse.org
- Add vala-bgo638902-shotwell-fix.patch to fix a build issue with
  shotwell 0.8.0. Based on patch from git.
* Tue Dec 28 2010 dimstar@opensuse.org
- Update to version 0.10.2:
  + Bug fixes and binding updates.
* Thu Nov 18 2010 vuntz@opensuse.org
- Update to version 0.10.1:
  + Remove outdated GTK+ 3 bindings.
  + Many bug fixes and binding updates.
* Sat Sep 18 2010 vuntz@opensuse.org
- Update to version 0.10.0:
  + Port GIR parser and writer to GIR version 1.2.
  + Update GLib bindings to 2.26 branch.
  + Bug fixes.
* Sat Sep  4 2010 dimstar@opensuse.org
- Update to version 0.9.8:
  + Add --fatal-warnings commandline option.
  + Deprecate string.len () in favor of string.length.
  + Deprecate use of D-Bus GLib in favor of GDBus.
  + Many bug fixes and binding updates.
* Tue Aug 24 2010 vuntz@opensuse.org
- Update summaries.
- Merge devel package in main package since vala is really a build
  tool. Add appropriate Provides/Obsoletes tags. Note that we'd
  want the vala-devel Provides in all cases since it's a build
  tool.
- Split the library in a libvala-0_10-0 subpackage, and split its
  development files in libvala-0_10-devel.
- Remove weird sed lines that were changing libtool.
- Add update-alternatives Requires(post/postun).
- Fix update-alternatives setup to use slaves, and only get a main
  alternative on which everything else depends.
* Fri Aug 20 2010 dimstar@opensuse.org
- Update to version 0.9.7:
  + Fix regression introduced by codegen refactoring.
* Wed Aug 18 2010 dimstar@opensuse.org
- Update to version 0.9.6:
  + Drop deprecated support for assigning to construct properties.
  + Some refactoring in the code generator.
  + Bug fixes in bindings and vapigen.
* Mon Aug  9 2010 dimstar@opensuse.org
- Update to version 0.9.5:
  + Add version suffix to support parallel installation.
  + Define VALA_X_Y according to compiler version.
  + Enable version header by default.
  + Add vala.m4 with VALA_CHECK_PACKAGES macro.
  + Add gedit-2.20 bindings
  + Add tokyocabinet bindings
  + Various improvements to the Dova profile.
  + Many bug fixes and binding updates.
- The non-versioned binaries are handled with update-alternatives,
  so that we have an easy play with upcoming versions, allowing to
  install them in parallel.
- Add fdupes BuildRequires and link duplicate files in /usr/share.
* Fri Aug  6 2010 vuntz@opensuse.org
- Update to version 0.9.4:
  + Append documentation comments to generated C files.
  + Skip <doc> tags in .gir files.
  + Various improvements to the Dova profile.
  + Many bug fixes and binding updates.
* Mon Jul 26 2010 dimstar@opensuse.org
- Update to version 0.9.3:
  + Support newlines in double quoted string literals.
  + Add experimental support for main blocks.
  + Add experimental vala tool to compile and run code.
  + Initial support for generic delegates.
  + Support using GClosure for delegate parameters.
  + Support GBoxed-based memory management.
  + Improvements to the .gir reader and writer.
  + Various improvements to the Dova profile.
  + Many bug fixes and binding updates.
* Mon Jun 21 2010 dimstar@opensuse.org
- Update to version 0.9.2:
  + Initial support for GDBus-based clients and servers.
  + Support implicit and explicit GVariant casts.
  + Add support for [Deprecated] attribute.
  + Add GenericArray as alternative binding to GPtrArray.
  + Add gdk-pixbuf-3.0, gdk-3.0, gdk-x11-3.0, and gtk+-3.0
    bindings.
  + Updates to the GLib bindings.
  + Many bug fixes.
- Changes from version 0.9.1:
  + Support constants in enums.
  + Deprecate +=/-= syntax to connect/disconnect signal handlers.
  + Add experimental support for Dova profile.
  + Update Genie parser.
  + Add clutter-gst-1.0 bindings.
  + Add gdu and gdu-gtk bindings.
  + Add libesmtp bindings.
  + Add mx-1.0 bindings.
  + Add orc-0.4 bindings.
  + Add rest-extras-0.6 bindings.
  + Updates to the GLib, GStreamer, Linux, SQLite, and other
    bindings
  + Many bug fixes.
* Thu Apr 29 2010 dimstar@opensuse.org
- Update to version 0.8.1:
  + Support constants in enums.
  + Add clutter-gst-1.0 bindings
  + Add gdu and gdu-gtk bindings.
  + Many bug fixes and binding updates.
* Wed Mar 31 2010 vuntz@opensuse.org
- Update to version 0.8.0:
  + Infer type arguments when calling generic methods.
  + Support `in' operator for arrays.
  + Add experimental support for regular expression literals.
  + Add experimental support for chained relational expressions.
  + Add va_list support.
  + Add clutter-gtk-0.10 bindings.
  + Add gdl-1.0 bindings.
  + Add gstreamer-app-0.10 bindings.
  + Add gstreamer-cdda-0.10 bindings.
  + Add gudev-1.0 bindings.
  + Add libgda-report-4.0 bindings.
  + Add libgvc (graphviz) bindings.
  + Add purple bindings.
  + Many bug fixes and binding updates.
* Fri Feb  5 2010 lmedinas@opensuse.org
- Update to version 0.7.10:
  + Support coalescing operator ??.
  + Support to_string and bitwise complement with enums.
  + Return handler id when connecting signal handlers.
  + Support struct comparison.
  + Support constructor chaining in structs.
  + Enforce protected member restrictions.
  + Improve performance of flow analysis.
  + Support automatic line continuations in Genie.
  + Improvements to the .gir reader and writer.
  + Add --enable-mem-profiler commandline option.
  + Many bug fixes and binding updates.
- Drop return-fix.patch: fixed upstream.
* Sun Dec 20 2009 vuntz@opensuse.org
- Update to version 0.7.9:
  + Support array and string slicing.
  + Add --symbols commandline option.
  + Add avahi-gobject bindings.
  + Add ccss-1 bindings.
  + Add libarchive bindings.
  + Add libmagic bindings.
  + Add readline bindings.
  + Add twitter-glib-1.0 bindings.
  + Many bug fixes and binding updates.
- Remove check for old version of openSUSE.
* Fri Nov 27 2009 dimstar@opensuse.org
- Update to version 0.7.8:
  + Support constructor chain up to GObject using Object (...).
  + Add syntax for string templates.
  + Support (!) non-null casts.
  + Many bug fixes and binding updates.
- Fixes from version 0.7.6:
  + Support `using' directives inside namespaces.
  + Use const only for immutable structs.
  + Support string marshalling for enums in D-Bus
- Fixes from version 0.7.5:
  + Update Genie parser
  + Add libgda-4.0 bindings
  + Many bug fixes for closures and async methods.
  + Add support for closures.
  + Improve support for asynchronous methods.
  + Support async methods in D-Bus servers.
  + Add clutter-1.0 bindings
  + Add GVariant, GSettings, and dconf bindings
  + Add linux, libnl-1, and libasound bindings
  + Add gnutls bindings
  + Add librest bindings
  + Many bug fixes and binding updates.
- Rebase return-fix.patch
- Drop vala-0.3.3-implicit-fortify-decl.patch, upstream fixed.
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Mon Aug  3 2009 dominique-obs@leuenberger.net
- Update to version 0.7.5:
  + Add support for static properties.
  + Add support for delegate properties.
  + Support virtual default handler for signals.
  + Add limited support for derived compact classes.
  + Add libgdata bindings
  + Add libusb-1.0 bindings
  + Many bug fixes and binding updates.
* Mon Jul 27 2009 dominique-obs@leuenberger.net
- Update to version 0.7.4:
  + Way too many changes since 0.3.3. See NEWS for details.
- Refactored retry-fix.patch. Patch rejected upstream, as the .c
  files are generated ones.
- Remove INSTALL from %%%%doc to fix a rpmlint warning.
* Tue Oct 14 2008 crrodriguez@suse.de
- fix implicit-fortify-decl errors
- correct -devel package requires
* Fri Sep 12 2008 mauro@suse.de
- Added return-fix.patch to fix the error " Program returns random
  data in a function".
* Fri Jul 25 2008 mauro@suse.de
- initial SUSE package
